@@ -38,8 +38,7 @@ void ExampleApplication::create_window(const Glib::RefPtr<Gio::File>& file)
 
   //Delete the window when it is hidden.
   //That's enough for this simple example.
-  window->signal_hide().connect(sigc::bind(sigc::mem_fun(*this,
-    &ExampleApplication::on_window_hide), window));
+  window->signal_hide().connect([window]() { delete window; });
 
   window->set_visible(true);
 
@@ -55,11 +54,6 @@ void ExampleApplication::create_window(const Glib::RefPtr<Gio::File>& file)
     std::cerr << "This file could not be loaded: " << file->get_path() << std::endl;
 }
 
-void ExampleApplication::on_window_hide(Gtk::Window* window)
-{
-  delete window;
-}
-
 void ExampleApplication::on_activate()
 {
   //std::cout << "debug1: " << G_STRFUNC << std::endl;
