@@ -1,5 +1,3 @@
-//$Id: packbox.h 705 2006-07-19 02:55:32Z jjongsma $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -24,12 +22,11 @@
 class PackBox : public Gtk::Box
 {
 public:
-  PackBox(bool homogeneous, int spacing, Gtk::PackOptions options, int padding = 0);
-  virtual ~PackBox();
+  PackBox(bool homogeneous = false, int spacing = 0, bool expand = false,
+    Gtk::Align align = Gtk::Align::FILL, int margin = 0);
 
 protected:
-  Gtk::Button m_button1, m_button2, m_button3;
-  Gtk::Button* m_pbutton4;
+  Gtk::Button m_buttons[4];
 };
 
 #endif //GTKMM_EXAMPLE_PACKBOX_H
