@@ -30,8 +30,8 @@ public:
 
 protected:
   Glib::RefPtr<Gtk::Builder> m_refBuilder;
-  Gtk::Stack* m_stack;
-  Gtk::MenuButton* m_gears;
+  Gtk::Stack* m_stack {nullptr};
+  Gtk::MenuButton* m_gears {nullptr};
 };
 
 #endif /* GTKMM_EXAMPLEAPPWINDOW_H */
