@@ -1,5 +1,3 @@
-//$Id: radiobuttons.h 2 2003-01-21 13:41:59Z murrayc $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,7 +19,8 @@
 
 #include <gtkmm/box.h>
 #include <gtkmm/window.h>
-#include <gtkmm/radiobutton.h>
+#include <gtkmm/button.h>
+#include <gtkmm/checkbutton.h>
 #include <gtkmm/separator.h>
 
 class RadioButtons : public Gtk::Window
@@ -36,7 +35,7 @@ protected:
 
   //Child widgets:
   Gtk::Box m_Box_Top, m_Box1, m_Box2;
-  Gtk::RadioButton m_RadioButton1, m_RadioButton2, m_RadioButton3;
+  Gtk::CheckButton m_RadioButton1, m_RadioButton2, m_RadioButton3;
   Gtk::Separator m_Separator;
   Gtk::Button m_Button_Close;
 };
