@@ -24,8 +24,6 @@ int main(int argc, char *argv[])
   auto app = Gtk::Application::create(
     "org.gtkmm.example", Gio::Application::Flags::NON_UNIQUE);
 
-  ExampleWindow window;
-
   //Shows the window and returns when it is closed.
-  return app->run(window, argc, argv);
+  return app->make_window_and_run<ExampleWindow>(argc, argv);
 }
