@@ -18,31 +18,33 @@
 #define GTKMM_CUSTOM_CONTAINER_MYCONTAINER_H
 
 #include <gtkmm/widget.h>
+#include <gtkmm/version.h>
+
+#define HAS_SIGNAL_DESTROY GTKMM_CHECK_VERSION(4,7,1)
 
 class MyContainer : public Gtk::Widget
 {
 public:
   MyContainer();
-  virtual ~MyContainer();
+  ~MyContainer() override;
 
-  void set_child_widgets(Gtk::Widget& child_one, Gtk::Widget& child_two);
+  void append(Gtk::Widget& child);
+  void prepend(Gtk::Widget& child);
+  void remove(Gtk::Widget& child);
 
 protected:
+  int get_nvis_children() const;
 
   //Overrides:
   Gtk::SizeRequestMode get_request_mode_vfunc() const override;
   void measure_vfunc(Gtk::Orientation orientation, int for_size, int& minimum, int& natural,
     int& minimum_baseline, int& natural_baseline) const override;
   void size_allocate_vfunc(int width, int height, int baseline) override;
-#if 0
-  void forall_vfunc(const ForeachSlot& slot) override;
 
-  void on_add(Gtk::Widget* child) override;
-  void on_remove(Gtk::Widget* child) override;
-  GType child_type_vfunc() const override;
+#if HAS_SIGNAL_DESTROY
+  // Signal handler:
+  void on_container_destroy();
 #endif
-  Gtk::Widget* m_child_one;
-  Gtk::Widget* m_child_two;
 };
 
 #endif //GTKMM_CUSTOM_CONTAINER_MYCONTAINER_H
