@@ -17,12 +17,10 @@
 #include "dndwindow.h"
 #include <gtkmm/application.h>
 
-int main (int argc, char *argv[])
+int main(int argc, char* argv[])
 {
   auto app = Gtk::Application::create("org.gtkmm.example");
 
-  DnDWindow dndWindow;
-
   //Shows the window and returns when it is closed.
-  return app->run(dndWindow, argc, argv);
+  return app->make_window_and_run<DnDWindow>(argc, argv);
 }
