@@ -18,16 +18,24 @@
 #include <gtkmm/application.h>
 #include <gtkmm/window.h>
 
+class ExampleWindow : public Gtk::Window
+{
+public:
+  ExampleWindow();
+
+protected:
+  Clock m_clock;
+};
+
+ExampleWindow::ExampleWindow()
+{
+  set_title("Cairomm Clock");
+  set_child(m_clock);
+}
+
 int main(int argc, char** argv)
 {
-   auto app = Gtk::Application::create("org.gtkmm.example");
+  auto app = Gtk::Application::create("org.gtkmm.example");
 
-   Gtk::Window win;
-   win.set_title("Cairomm Clock");
-
-   Clock c;
-   win.add(c);
-   c.show();
-
-   return app->run(win, argc, argv);
+  return app->make_window_and_run<ExampleWindow>(argc, argv);
 }
