@@ -17,12 +17,10 @@
 #include <gtkmm.h>
 #include "examplewindow.h"
 
-int main(int argc, char *argv[])
+int main(int argc, char* argv[])
 {
   auto app = Gtk::Application::create("org.gtkmm.example");
 
-  ExampleWindow window(app);
-
   //Shows the window and returns when it is closed.
-  return app->run(window, argc, argv);
+  return app->make_window_and_run<ExampleWindow>(argc, argv, app);
 }
