@@ -36,7 +36,7 @@ protected:
 
   void on_hide() override;
 
-  bool on_drawing_area_draw(const Cairo::RefPtr<Cairo::Context>& cr);
+  void on_drawing_area_draw(const Cairo::RefPtr<Cairo::Context>& cr, int width, int height);
 
   //PrintOperationPreview signal handlers:
   void on_popreview_ready(const Glib::RefPtr<Gtk::PrintContext>& print_ctx);
@@ -47,14 +47,14 @@ protected:
   Glib::RefPtr<Gtk::PrintOperationPreview> m_refPreview;
   Glib::RefPtr<Gtk::PrintContext> m_refPrintContext;
   Glib::RefPtr<Pango::Layout> m_refLayout;
-  // Gdk::DrawingContext is new in gtkmm 3.22 (and 3.21.x, where x > 2)
-  Glib::RefPtr<Gdk::DrawingContext> m_refDrawingContext;
+  Cairo::RefPtr<Cairo::Context> m_refCairoContext;
 
   Gtk::Box m_VBox;
   Gtk::Box m_HBox;
   Glib::RefPtr<Gtk::Adjustment> m_SpinAdjustment;
   Gtk::SpinButton m_PageSpin;
   Gtk::Button m_CloseButton;
+  Gtk::ScrolledWindow m_ScrolledWindow;
   Gtk::DrawingArea m_DrawingArea;
 
   int m_Page;
