@@ -18,7 +18,6 @@
 #define GTKMM_EXAMPLEWINDOW_H
 
 #include <gtkmm.h>
-#include <memory>
 
 class ExampleWindow : public Gtk::Window
 {
@@ -31,7 +30,7 @@ protected:
   void on_menu_file_files_dialog();
   void on_menu_file_quit();
   void on_menu_file_new();
-  void on_dialog_response(int response_id);
+  void on_dialog_finish(Glib::RefPtr<Gio::AsyncResult>& result);
 
   //Child widgets:
   Gtk::Box m_Box;
@@ -40,8 +39,7 @@ protected:
   Glib::RefPtr<Gio::SimpleActionGroup> m_refActionGroup;
 
   Glib::RefPtr<Gtk::RecentManager> m_refRecentManager;
-
-  std::unique_ptr<Gtk::FileChooserDialog> m_pDialog;
+  Glib::RefPtr<Gtk::FileDialog> m_refFileDialog;
 };
 
 #endif //GTKMM_EXAMPLEWINDOW_H
