@@ -19,10 +19,8 @@
 
 int main(int argc, char *argv[])
 {
-  auto app = Gtk::Application::create(argc, argv, "org.gtkmm.example");
-
-  ExampleWindow window(app);
+  auto app = Gtk::Application::create("org.gtkmm.example");
 
   //Shows the window and returns when it is closed.
-  return app->run(window);
+  return app->make_window_and_run<ExampleWindow>(argc, argv, app);
 }
