@@ -21,9 +21,6 @@ int main(int argc, char *argv[])
 {
   auto app = Gtk::Application::create("org.gtkmm.example.searchbar");
 
-  ExampleWindow window;
-
   // Shows the window and returns when it is closed.
-  return app->run(window, argc, argv);
+  return app->make_window_and_run<ExampleWindow>(argc, argv);
 }
-
