@@ -21,6 +21,5 @@ int main (int argc, char *argv[])
 {
   auto app = Gtk::Application::create("org.gtkmm.example");
 
-  DnDWindow dndWindow;
-  return app->run(dndWindow, argc, argv); //Shows the window and returns when it is closed.
+  return app->make_window_and_run<DnDWindow>(argc, argv); //Shows the window and returns when it is closed.
 }
